@@ -6,7 +6,7 @@ from django.utils.translation import ugettext_lazy as _
 from rest_framework import serializers, exceptions
 
 from notification_system.models import (NotificationEvent, EmailTemplate, Attachment, SmtpProvider, NotificationGroup,
-                                        OutgoingMessage, Media)
+                                        OutgoingMessage, Media, Contact, ContactGroup)
 from notification_system.utils import get_user_common_data
 
 User = get_user_model()
@@ -26,6 +26,42 @@ class EmailTemplateSerializer(serializers.ModelSerializer):
         fields = ['id', 'title', 'subject', 'content']
 
 
+class ContactSerializer(serializers.ModelSerializer):
+    class Meta:
+        model = Contact
+        fields = ['id', 'name', 'email']
+
+
+class ContactGroupSerializer(serializers.ModelSerializer):
+    contacts_detail = serializers.SerializerMethodField(read_only=True)
+
+    class Meta:
+        model = ContactGroup
+        fields = ['id', 'name', 'contacts', 'contacts_detail']
+        extra_kwargs = {
+            'contacts': {'write_only': True}
+        }
+
+    def get_contacts_detail(self, obj):
+        contacts = obj.contacts.filter(is_active=True)
+        return ContactSerializer(instance=contacts, many=True, context=self.context).data
+
+    def validate_contacts(self, value):
+        user = self.context['request'].user
+        for contact in value:
+            if not contact.is_active or contact.owner != user:
+                message = _("You do not have permission to access contact with id: {}.")
+                raise exceptions.ValidationError(detail=message.format(contact.id))
+
+        return value
+
+
+class MinimalContactGroupSerializer(serializers.ModelSerializer):
+    class Meta:
+        model = ContactGroup
+        fields = ['id', 'name']
+
+
 class MediaSerializer(serializers.ModelSerializer):
     class Meta:
         model = Media
@@ -57,15 +93,18 @@ class NotificationEventSerializer(serializers.ModelSerializer):
                                                             read_only=True)
     notification_groups_detail = MinimalNotificationGroupSerializer(source='notification_groups', many=True,
                                                                     read_only=True)
+    contact_groups_detail = MinimalContactGroupSerializer(source='contact_groups', many=True, read_only=True)
     recipients = serializers.PrimaryKeyRelatedField(many=True, queryset=User.objects.filter(is_active=True),
                                                     required=False, write_only=True)
+    contact_groups = serializers.PrimaryKeyRelatedField(many=True, queryset=ContactGroup.actives.all(),
+                                                        required=False, write_only=True)
 
     class Meta:
         model = NotificationEvent
         fields = ['id', 'title', 'smtp_provider', 'smtp_provider_detail', 'template', 'template_detail', 'subject',
                   'content', 'notification_event_type', 'notification_event_type_display', 'notification_groups',
-                  'notification_groups_detail', 'attachments', 'recipients', 'is_sent', 'sent_time', 'created_time',
-                  'updated_time']
+                  'notification_groups_detail', 'contact_groups_detail', 'attachments', 'recipients', 'is_sent',
+                  'contact_groups', 'sent_time', 'created_time', 'updated_time']
         read_only_fields = ['is_sent', 'sent_time', 'created_time', 'updated_time']
 
         extra_kwargs = {
@@ -116,6 +155,15 @@ class NotificationEventSerializer(serializers.ModelSerializer):
 
         return value
 
+    def validate_contact_groups(self, value):
+        user = self.context['request'].user
+        for contact_group in value:
+            if not contact_group.is_active or contact_group.owner != user:
+                message = _("You do not have permission to access contact groups with id: {}.")
+                raise exceptions.ValidationError(detail=message.format(contact_group.id))
+
+        return value
+
     def validate_smtp_provider(self, value):
         if value:
             if (not value.is_active) or (not value.users.filter(pk__in=[self.context['request'].user.id]).exists()):
@@ -141,6 +189,7 @@ class NotificationEventDetailSerializer(serializers.ModelSerializer):
                                                             read_only=True)
     notification_groups_detail = MinimalNotificationGroupSerializer(source='notification_groups', many=True,
                                                                     read_only=True)
+    contact_groups_detail = MinimalContactGroupSerializer(source='contact_groups', many=True, read_only=True)
     total_count = serializers.IntegerField(read_only=True, default=0)
     sent_status_count = serializers.IntegerField(read_only=True, default=0)
     pending_status_count = serializers.IntegerField(read_only=True, default=0)
@@ -160,10 +209,10 @@ class NotificationEventDetailSerializer(serializers.ModelSerializer):
         model = NotificationEvent
         fields = ['id', 'title', 'smtp_provider_detail', 'template_detail', 'subject', 'content',
                   'notification_event_type', 'notification_event_type_display', 'notification_groups_detail',
-                  'attachments', 'is_sent', 'sent_time', 'created_time', 'updated_time', 'total_count',
-                  'sent_status_count', 'pending_status_count', 'failed_status_count', 'bounce_status_count',
-                  'complaint_status_count', 'delivery_status_count', 'amazon_send_status_count', 'reject_status_count',
-                  'open_status_count', 'click_status_count', 'rendering_failure_status_count',
+                  'contact_groups_detail', 'attachments', 'is_sent', 'sent_time', 'created_time', 'updated_time',
+                  'total_count', 'sent_status_count', 'pending_status_count', 'failed_status_count',
+                  'bounce_status_count', 'complaint_status_count', 'delivery_status_count', 'amazon_send_status_count',
+                  'reject_status_count', 'open_status_count', 'click_status_count', 'rendering_failure_status_count',
                   'delivery_delay_status_count', 'subscription_status_count']
 
 
