@@ -14,6 +14,7 @@ def broadcast_event_messages_to_recipients(event_message_id):
         subject = notification_event.get_subject()
         html_content = notification_event.get_content()
         recipients = notification_event.get_recipients()
+        contacts = notification_event.get_contacts()
         email_from = notification_event.smtp_provider.email_from
         smtp_config = notification_event.smtp_provider.get_smtp_config()
         attachments = [attachment.file.path for attachment in notification_event.attachments.all()]
@@ -27,6 +28,21 @@ def broadcast_event_messages_to_recipients(event_message_id):
                                                             notification_event=notification_event.id)
             notification_handler.send()
 
+        for contact in contacts:
+            email = contact.get('email')
+            context = {
+                'email': email,
+                'username': email,
+                'first_name': contact.get('contact_name'),
+            }
+            notification_handler = EmailNotificationHandler(subject=subject, recipient=email,
+                                                            email_from=email_from, context=context,
+                                                            content=html_content, smtp_config=smtp_config,
+                                                            attachments=attachments,
+                                                            notification_event=notification_event.id)
+            notification_handler.send()
+
+
     else:
         queue_name = NotificationHandler.INTERNAL_MESSAGE_NOTIFICATION_QUEUE_NAME
         notification_system_send_internal_message.apply_async(args=(notification_event.pk,), queue=queue_name)
