@@ -25,6 +25,7 @@ def notification_system_send_internal_message(notification_event_id):
     subject = notification_event.get_subject()
     content = notification_event.get_content()
     recipients = notification_event.get_recipients(check_email_isnull=True)
+    contacts = notification_event.get_contacts()
 
     outgoing_message_objects = []
     for user in recipients:
@@ -36,6 +37,19 @@ def notification_system_send_internal_message(notification_event_id):
                                                   outgoing_message_type=OutgoingMessage.TYPE_INTERNAL_MESSAGE)
         outgoing_message_objects.append(outgoing_message_object)
 
+    for contact in contacts:
+        email = contact.get('email')
+        context = {
+            'email': email,
+            'username': email,
+            'first_name': contact.get('contact_name'),
+        }
+        outgoing_message_object = OutgoingMessage(subject=subject, recipient=email, context=dict(context),
+                                                  content=content, notification_event=notification_event,
+                                                  status=OutgoingMessage.STATUS_SENT,
+                                                  outgoing_message_type=OutgoingMessage.TYPE_INTERNAL_MESSAGE)
+        outgoing_message_objects.append(outgoing_message_object)
+
     if outgoing_message_objects:
         try:
             OutgoingMessage.objects.bulk_create(outgoing_message_objects)
